==> react-components-library-0.0.27.tgz: package/src/Form/DateInput/index.tsx <==
import React from "react";
import { useClickAway } from "use-click-away";
import { FormElement } from "../formElement";
import { Input } from "../Input";
import { Button, ButtonProps } from "../../Button";
import PropTypes from "prop-types";
import { makeParserPair } from "./formatter";
import styling from "@devcake/styling";
import colors from "../../Button/colors";
import { Dropdown } from "./dropdown";
import { Icon } from "../../Icon";
import { useStyle } from "../../Scope";
import { Color, ColorPropType, Type, TypePropType } from "../../types";

styling.link("components.dateinput.invalid", "components.form.invalid");
styling.link("components.dateinput.disabled", "components.form.disabled");
styling.link("components.dateinput.icons.calendar", "components.icons.calendar");
styling.setDefault("components.dateinput.valid", "");
styling.setDefault("components.dateinput.inset", "rounded-l-none");

export type DateInputProps = FormElement<Date> & {
  buttonType?: Type;
  color?: Color;
  format?: Intl.DateTimeFormatOptions;
  locale?: string;
}

export const DateInput: React.FunctionComponent<DateInputProps> = (props) => {
    const { buttonType, color, className, disabled, format, label, locale, nullable, placeholder } = props;
    const onChange = "onChange" in props ? props.onChange : () => null;
    const value = "value" in props ? props.value : null;

    const [innerValue, setInnerValue] = React.useState("");
    const [isValid, setIsValid] = React.useState(true);
    const [showPicker, setShowPicker] = React.useState(false);

    const ref = React.createRef<HTMLDivElement>();
    useClickAway(ref, () => setShowPicker(false));

    const [formatter, parser] = React.useMemo(() => makeParserPair(locale, format), [locale, format]);

    const updateInnerValue: (value: string, callback?: (value: Date) => void) => void = (value, callback = null) => {
      setInnerValue(value);
      const parsed = parser(value);
      let cbValue = null;
      if (nullable && innerValue === "") {
        setIsValid(true);
      } else if (parsed === false) {
        setIsValid(false);
      } else {
        setIsValid(true);
        cbValue = parsed;
      }

      if (callback) callback(cbValue);
    };

    React.useEffect(() => updateInnerValue(formatter(value)), [value, formatter]);

    const [validStyle, invalidStyle, disabledStyle, insetStyle, icon] = useStyle(["valid", "invalid", "disabled", "inset", "icons.calendar"], "components.dateinput");

    return (
      <Input
        className={[
          className,
          isValid ? validStyle : invalidStyle
        ].join(" ")}
        disabled={disabled}
        label={label}
        nullable={false}
        value={innerValue}
        onChange={val => updateInnerValue(val || "", onChange)}
        placeholder={placeholder}
        inset={(<div ref={ref}>
          <Button
            color={color}
            type={buttonType}
            className={[
              disabled ? disabledStyle : "",
              insetStyle
            ].join(" ")}
            onClick={disabled ? null : () => setShowPicker(!showPicker)}
          >
            <Icon icon={icon} className="w-5 h-5" />
          </Button>
          {showPicker && <Dropdown
            color={color}
            value={parser(innerValue) || new Date()}
            locale={locale}
            set={date => {
              updateInnerValue(formatter(date), onChange);
              setShowPicker(false);
            }}
          />}
        </div>)}
      />
    );
  }
;

//@ts-ignore TS is complaining about nullable not being a boolean, somehow
DateInput.propTypes = {
  buttonType: TypePropType,
  color: ColorPropType,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  label: PropTypes.node,
  locale: PropTypes.string,
  nullable: PropTypes.bool,
  placeholder: PropTypes.string,
  onChange: PropTypes.func,
  value: PropTypes.instanceOf(Date)
};
DateInput.defaultProps = {
  buttonType: "secondary",
  color: "indigo",
  disabled: false,
  locale: "nl-NL",
  nullable: true
};

==> react-components-library-0.0.31.tgz: package/src/Form/DateInput/index.tsx <==
import React from "react";
import { useClickAway } from "use-click-away";
import { FormElement } from "../formElement";
import { Input } from "../Input";
import { Button, ButtonProps } from "../../Button";
import PropTypes from "prop-types";
import { makeParserPair } from "./formatter";
import styling from "@devcake/styling";
import colors from "../../Button/colors";
import { Dropdown } from "./dropdown";
import { Icon } from "../../Icon";
import { useStyle } from "../../Scope";
import { Color, ColorPropType, Type, TypePropType } from "../../types";

styling.link("components.dateinput.invalid", "components.form.invalid");
styling.link("components.dateinput.disabled", "components.form.disabled");
styling.link("components.dateinput.icons.calendar", "components.icons.calendar");
styling.setDefault("components.dateinput.valid", "");
styling.setDefault("components.dateinput.inset", "rounded-l-none");

export type DateInputProps = FormElement<Date> & {
  buttonType?: Type;
  color?: Color;
  format?: Intl.DateTimeFormatOptions;
  locale?: string;
}

export const DateInput: React.FunctionComponent<DateInputProps> = (props) => {
    const { buttonType, color, className, disabled, format, label, locale, nullable, placeholder } = props;
    const onChange = "onChange" in props ? props.onChange : () => null;
    const value = "value" in props ? props.value : null;

    const [innerValue, setInnerValue] = React.useState("");
    const [isValid, setIsValid] = React.useState(true);
    const [showPicker, setShowPicker] = React.useState(false);

    const ref = React.createRef<HTMLDivElement>();
    useClickAway(ref, () => setShowPicker(false));

    const [formatter, parser] = React.useMemo(() => makeParserPair(locale, format), [locale, format]);

    const updateInnerValue: (value: string, callback?: (value: Date) => void) => void = (value, callback = null) => {
      setInnerValue(value);
      const parsed = parser(value);
      let cbValue = null;
      if (nullable && value === "") {
        setIsValid(true);
      } else if (parsed === false) {
        setIsValid(false);
      } else {
        setIsValid(true);
        cbValue = parsed;
      }

      if (callback) callback(cbValue);
    };

    React.useEffect(() => updateInnerValue(formatter(value)), [value, formatter]);

    const [validStyle, invalidStyle, disabledStyle, insetStyle, icon] = useStyle(["valid", "invalid", "disabled", "inset", "icons.calendar"], "components.dateinput");

    return (
      <Input
        className={[
          className,
          isValid ? validStyle : invalidStyle
        ].join(" ")}
        disabled={disabled}
        label={label}
        nullable={false}
        value={innerValue}
        onChange={val => updateInnerValue(val || "", onChange)}
        placeholder={placeholder}
        inset={(<div ref={ref}>
          <Button
            color={color}
            type={buttonType}
            className={[
              disabled ? disabledStyle : "",
              insetStyle
            ].join(" ")}
            onClick={disabled ? null : () => setShowPicker(!showPicker)}
          >
            <Icon icon={icon} className="w-5 h-5" />
          </Button>
          {showPicker && <Dropdown
            color={color}
            value={parser(innerValue) || new Date()}
            locale={locale}
            set={date => {
              updateInnerValue(formatter(date), onChange);
              setShowPicker(false);
            }}
          />}
        </div>)}
      />
    );
  }
;

//@ts-ignore TS is complaining about nullable not being a boolean, somehow
DateInput.propTypes = {
  buttonType: TypePropType,
  color: ColorPropType,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  label: PropTypes.node,
  locale: PropTypes.string,
  nullable: PropTypes.bool,
  placeholder: PropTypes.string,
  onChange: PropTypes.func,
  value: PropTypes.instanceOf(Date)
};
DateInput.defaultProps = {
  buttonType: "secondary",
  color: "indigo",
  disabled: false,
  locale: "nl-NL",
  nullable: true
};
